@@ -100,7 +100,10 @@ class V4LCameraCapture(Producer):
                 break
         if config is None:
             raise RuntimeError("expected capture format is unsupported")
-        fmt = self.video.set_format(config, expected_format=expected_format)
+        if format_selector == V4LCameraCapture.FormatSelector.MAXIMUM:
+            fmt = self.video.set_format(config, expected_format=expected_format)
+        else:
+            fmt = self.video.set_format(config, width, height, expected_format=expected_format)
         self.capture_width, self.capture_height, self.capture_format = fmt
         self.video.set_framerate(config)
         # video.set_rotation(90)
